#!/bin/bash
. "$(dirname "$0")"/fixDNS.sh

# @param String message - The message to log
readonly LOG_MESSAGE_COMMAND=$(basename "${0}")
logMessage()
{
	echo "$(date '+%a %b %e %T %Y') $LOG_MESSAGE_COMMAND: "${@} >> "${SCRIPT_LOG_FILE}"
}

restoreIPv6()
{
	logMessage "Restoring previously saved IPv6 configuration...";
	IPV6_TYPE=`defaults read com.tunnelbear.mac.TunnelBear savedIPv6.type`;
	logMessage "IPv6 Configuration Type: $IPV6_TYPE";

	if [ "$IPV6_TYPE" == 'Off' ] ; then
		return
	fi

	if [ $IPV6_TYPE == 'LinkLocal' ] ; then
		networksetup -setv6LinkLocal $DEFAULT_SERVICE
		return
	fi

	if [ $IPV6_TYPE == 'Automatic' ] ; then
		networksetup -setv6automatic $DEFAULT_SERVICE
		return
	fi

	if [ $IPV6_TYPE == 'Manual' ] ; then
		IPV6_ADDRESS=`defaults read com.tunnelbear.Mac.TunnelBear savedIPv6.address`
		IPV6_ROUTER=`defaults read com.tunnelbear.Mac.TunnelBear savedIPv6.router`
		IPV6_PREFLEN=`defaults read com.tunnelbear.Mac.TunnelBear savedIPv6.preflen`

		logMessage "Address: $IPV6_ADDRESS"
		logMessage "Router: $IPV6_ROUTER"
		logMessage "Prefix Length: $IPV6_PREFLEN"

		networksetup -setv6manual $DEFAULT_SERVICE \
			$IPV6_ADDRESS $IPV6_PREFLEN $IPV6_ROUTER
		return
	fi
}

stopVigilant()
{
  logMessage $(pfctl -a 'com.tunnelbear' -F all)
}


################# START HERE ####################

readonly SCRIPT_LOG_FILE="/var/log/tbeard/vigilant.log"

DEFAULT_INTERFACE=`netstat -nr |
		grep -m1 default |
		awk '{ if ($1 == "default") print $NF }'`

DEFAULT_SERVICE=`networksetup -listnetworkserviceorder |
		grep -m1 $DEFAULT_INTERFACE |
		awk '{ split($0, a, ":"); split(a[2], b, ","); print b[1] }' |
		sed -e 's/^[ \t]*//'`

logMessage "Default Interface: $DEFAULT_INTERFACE"
logMessage "Default Service: $DEFAULT_SERVICE"

restoreIPv6;
logMessage "Resetting DNS"
reset_dns

stopVigilant;

